# stativ

Tripod (Denish: stativ) - manage the back end of Binaries Repository Management (BRM) systems like a tripod: per prefix, backup, and delta store.

[License: MIT](https://git.sr.ht/~sthagen/stativ/tree/default/item/LICENSE)

[![version](https://img.shields.io/pypi/v/stativ.svg?style=flat)](https://pypi.python.org/pypi/stativ/)
[![downloads](https://pepy.tech/badge/stativ/month)](https://pepy.tech/project/stativ)
[![wheel](https://img.shields.io/pypi/wheel/stativ.svg?style=flat)](https://pypi.python.org/pypi/stativ/)
[![supported-versions](https://img.shields.io/pypi/pyversions/stativ.svg?style=flat)](https://pypi.python.org/pypi/stativ/)
[![supported-implementations](https://img.shields.io/pypi/implementation/stativ.svg?style=flat)](https://pypi.python.org/pypi/stativ/)

## Documentation

User and developer [documentation of stativ](https://codes.dilettant.life/docs/stativ).

## Bug Tracker

Feature requests and bug reports are bested entered in the [todos of stativ](https://todo.sr.ht/~sthagen/stativ).
## Primary Source repository

The primary source repository of [stativ is at sourcehut](https://git.sr.ht/~sthagen/stativ)
a collection of tools useful for software development.

## Status

Experimental.

**Note**: The default branch is `default`.
